import os
import shutil
import argparse

from .versionbumpr import load_file, update_setup_py


def main():
	argparser = argparse.ArgumentParser(description="Bump your setup.py's release version.")
	argparser.add_argument("path_to_setup_py", 
		type=str,
		default="",
		help="Path to your package's setup.py. Required")
	argparser.add_argument("-b", 
		type=str,
		default="minor",
		choices=["major", "minor", "hotfix"],
		help="""Type of version bump to perform. Defaults to "minor", disregarded if -v flag is provided.
		""")
	argparser.add_argument("-v",
		type=str,
		default="",
		help="The version number you want to bump your setup.py to.")
	argparser.add_argument("-d",
		action="store_true",
		help="If this flag is provided, the autogenerated [filename].old file will be deleted. Defaults to False.")
	
	parsed_args = argparser.parse_args()

	filename = os.path.abspath(parsed_args.path_to_setup_py)
	
	file_lines = load_file(filename)

	updated_setup = update_setup_py(file_lines, parsed_args.b, parsed_args.v)

	shutil.copyfile(filename, filename+".old")

	with open(filename, "w") as cfg:
		cfg.writelines(updated_setup)

	if parsed_args.d:
		os.remove(filename+".old")